pub struct ProviderInvocationContext {
pub request_id: String,
pub actor_id: Option<String>,
pub actor_scopes: Vec<String>,
pub traceparent: Option<String>,
pub tracestate: Option<String>,
pub progress: ProviderProgressReporter,
}Expand description
Authenticated, traceable context carried into an isolated provider runtime.
Fields
request_id: Stringactor_id: Option<String>actor_scopes: Vec<String>traceparent: Option<String>tracestate: Option<String>progress: ProviderProgressReporterHost-owned channel used to return capability progress to the surface that initiated this invocation.