pub struct ProviderProgressEvent {
pub current: u64,
pub total: Option<u64>,
pub message: Option<String>,
}Expand description
One bounded progress notification emitted by an isolated provider.
Fields
current: u64total: Option<u64>message: Option<String>Trait Implementations
Sourceimpl Clone for ProviderProgressEvent
impl Clone for ProviderProgressEvent
Sourcefn clone(&self) -> ProviderProgressEvent
fn clone(&self) -> ProviderProgressEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProviderProgressEvent
impl Debug for ProviderProgressEvent
Sourceimpl<'de> Deserialize<'de> for ProviderProgressEvent
impl<'de> Deserialize<'de> for ProviderProgressEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ProviderProgressEvent
impl PartialEq for ProviderProgressEvent
Sourcefn eq(&self, other: &ProviderProgressEvent) -> bool
fn eq(&self, other: &ProviderProgressEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProviderProgressEvent
impl Serialize for ProviderProgressEvent
impl Eq for ProviderProgressEvent
impl StructuralPartialEq for ProviderProgressEvent